﻿using System;
using CoreGraphics;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace StackingColumnSeries
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
		}

		NSMutableArray DataPoints;
		NSMutableArray DataPoints1;
		NSMutableArray LineDataPoints;
		SFChart chart;
		public override void ViewDidLoad()
		{
			base.ViewDidLoad();
			chart = new SFChart();
			chart.EdgeInsets = new UIEdgeInsets(25, 10, 10, 10);

			GetDataPoints();
			NSMutableArray CustomColors = GetCustomColors(DataPoints);

			SFCategoryAxis primaryAxis = new SFCategoryAxis();
			primaryAxis.LabelStyle.LabelsPosition = SFChartAxisElementPosition.Inside;
			primaryAxis.LabelStyle.Font = UIFont.SystemFontOfSize(20);
			primaryAxis.MajorTickStyle.LineSize = 0;
			primaryAxis.LabelRotationAngle = 270;
			primaryAxis.PlotOffset = 10;
			primaryAxis.ShowMajorGridLines = false;
			chart.PrimaryAxis = primaryAxis;

			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			secondaryAxis.ShowMajorGridLines = false;
			chart.SecondaryAxis = secondaryAxis;

			ChartDataModel dataModel = new ChartDataModel(DataPoints,DataPoints1,LineDataPoints,CustomColors);
			chart.DataSource = dataModel as SFChartDataSource;
			this.View.AddSubview(chart);
		}

		public void GetDataPoints()
		{
			DataPoints = new NSMutableArray();
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("January"), NSObject.FromObject(46)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("February"), NSObject.FromObject(47)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("March"), NSObject.FromObject(80)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("April"), NSObject.FromObject(40)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("May"), NSObject.FromObject(53)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("June"), NSObject.FromObject(38)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("July"), NSObject.FromObject(48)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("August"), NSObject.FromObject(55)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("September"), NSObject.FromObject(51)));
			DataPoints.Add(new SFChartDataPoint(NSObject.FromObject("October"), NSObject.FromObject(51)));
		}

		public NSMutableArray GetCustomColors( NSMutableArray DataPoints)
		{
			NSMutableArray array = new NSMutableArray();
			DataPoints1 = new NSMutableArray();
			LineDataPoints = new NSMutableArray();

			for (nuint i = 0; i < DataPoints.Count; i++)
			{
				SFChartDataPoint datapoint = DataPoints.GetItem<SFChartDataPoint>((nuint)i);
				double yValue = ((NSNumber)datapoint.YValue).DoubleValue;

				if (yValue > 50)
					array.Add(UIColor.FromRGB(161.0f / 255.0f, 199.0f / 255.0f, 247.0f / 255.0f));
				else
					array.Add(UIColor.FromRGB(251.0f / 255.0f, 194.0f / 255.0f, 45.0f / 255.0f));

				DataPoints1.Add(new SFChartDataPoint(datapoint.XValue, NSObject.FromObject(100 - yValue)));
				LineDataPoints.Add(new SFChartDataPoint(datapoint.XValue, NSObject.FromObject(50)));
			}

			return array;
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLayoutSubviews()
		{
			base.ViewDidLayoutSubviews();
			chart.Frame = new CGRect(0, 0, this.View.Frame.Width, this.View.Frame.Height - 10);
			chart.PrimaryAxis.LabelStyle.Margin = new UIEdgeInsets(0, chart.Frame.Size.Height / 2 - 70, 0, 0);
		}
	}

	public class ChartDataModel : SFChartDataSource
	{
		public NSMutableArray DataPoints
		{
			get;
			set;
		}

		public NSMutableArray DataPoints1
		{
			get;
			set;
		}

		public NSMutableArray LineDataPoints
		{
			get;
			set;
		}

		public NSMutableArray CustomColors
		{
			get;
			set;
		}

		public ChartDataModel(NSMutableArray dataPoints,NSMutableArray dataPoints1,NSMutableArray lineDataPoints, NSMutableArray customColors)
		{
			DataPoints = dataPoints;
			DataPoints1 = dataPoints1;
			LineDataPoints = lineDataPoints;
			CustomColors = customColors;
		}

		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 3;
		}

		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			if (index == 0)
			{
				SFLineSeries series = new SFLineSeries();
				series.Color = UIColor.FromRGB(71.0f / 255.0f, 150.0f / 255.0f, 105.0f / 255.0f);
				series.LineWidth = 3;
				series.XAxis = new SFNumericalAxis();
				series.XAxis.ShowMajorGridLines = false;
				series.XAxis.Visible = false;
				return series;
			}
			else if (index == 1)
			{
				SFStackingColumnSeries series = new SFStackingColumnSeries();
				series.ColorModel.Palette = SFChartColorPalette.Custom;
				series.ColorModel.CustomColors = CustomColors;
				return series;
			}
			else
			{
				SFStackingColumnSeries series = new SFStackingColumnSeries();
				series.Color = UIColor.FromRGB(200.0f / 255.0f, 200.0f / 255.0f, 201.0f / 255.0f);
				return series;
			}
		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			if (seriesIndex == 0)
				return LineDataPoints.GetItem<SFChartDataPoint>((nuint)index);
			else if (seriesIndex == 1)
				return DataPoints.GetItem<SFChartDataPoint>((nuint)index);
			else
				return DataPoints1.GetItem<SFChartDataPoint>((nuint)index);
		}

		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			if (index == 0)
				return (nint)LineDataPoints.Count;
			else if (index == 1)
				return (nint)DataPoints.Count;
			else
				return (nint)DataPoints1.Count;
		}
	}
}

